@@ -1,8 +1,5 @@
 package Pg::DatabaseManager;
-BEGIN {
-  $Pg::DatabaseManager::VERSION = '0.05';
-}
-
+$Pg::DatabaseManager::VERSION = '0.06';
 use Moose;
 
 use autodie;
@@ -499,8 +496,8 @@ sub _msg {
 
     my $msg = shift;
 
-    $msg =~ s/\%{app_name}/$self->app_name()/eg;
-    $msg =~ s/\%{db_name}/$self->db_name()/eg;
+    $msg =~ s/\%\{app_name\}/$self->app_name()/eg;
+    $msg =~ s/\%\{db_name\}/$self->db_name()/eg;
 
     print "  $msg\n\n";
 }
@@ -511,17 +508,19 @@ __PACKAGE__->meta()->make_immutable();
 
 # ABSTRACT: Manage installation and migration of an application's (Postgres) database
 
-
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Pg::DatabaseManager - Manage installation and migration of an application's (Postgres) database
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -539,7 +538,7 @@ or subclass it ...
 
   has '+app_name' => ( default => 'MyApp' );
 
-  has '+contrib_files => ( default => [ 'citext.sql' ] );
+  has '+contrib_files' => ( default => [ 'citext.sql' ] );
 
 =head1 DESCRIPTION
 
@@ -759,7 +758,3 @@ This is free software, licensed under:
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
